==> union-update-2.10.11.tgz: package/README.md <==
Gives values present in any array. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]

> Alternatives: [union], [union$].<br>
> Similar: [union], [intersection], [difference], [symmetricDifference].

> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

<br>

```javascript
array.union$(x, y, [fc], [fm]);
// x:  an array (updated)
// y:  another array
// fc: compare function (a, b)
// fm: map function (v, i, x)
// --> x
```
> :stopwatch: Compare function => O(n²).

```javascript
const array = require('extra-array');

var x = [1, 2, 3, 4];
var y = [2, 3, 5];
array.union$(x, y);
// [ 1, 2, 3, 4, 5 ]

x;
// [ 1, 2, 3, 4, 5 ]

var x = [1, 2, 3, 4];
var y = [-2, -3, -5];
array.union$(x, y, (a, b) => Math.abs(a) - Math.abs(b));
// [ 1, 2, 3, 4, -5 ]

var x = [1, 2, 3, 4];
array.union$(x, y, null, v => Math.abs(v));
// [ 1, 2, 3, 4, -5 ]
```

<br>
<br>


## References

- [Data.Set.union: Haskell](http://hackage.haskell.org/package/containers-0.6.2.1/docs/Data-Set.html#v:union)
- [Set.union: Python](https://www.programiz.com/python-programming/methods/set/union)
- [_.union: lodash](https://lodash.com/docs/4.17.15#union)
- [_.unionBy: lodash](https://lodash.com/docs/4.17.15#unionBy)
- [_.unionWith: lodash](https://lodash.com/docs/4.17.15#unionWith)
- [Array.union: sugarjs](https://sugarjs.com/docs/#/Array/union)

[:running:]: https://npm.runkit.com/@extra-array/union-update
[:package:]: https://www.npmjs.com/package/@extra-array/union-update
[:moon:]: https://www.npmjs.com/package/@extra-array/union-update.min
[:ledger:]: https://unpkg.com/@extra-array/union-update/
[union]: https://github.com/nodef/extra-array/wiki/union
[union$]: https://github.com/nodef/extra-array/wiki/union$
[intersection]: https://github.com/nodef/extra-array/wiki/intersection
[difference]: https://github.com/nodef/extra-array/wiki/difference
[unique]: https://github.com/nodef/extra-array/wiki/unique
[isUnique]: https://github.com/nodef/extra-array/wiki/isUnique
[isDisjoint]: https://github.com/nodef/extra-array/wiki/isDisjoint
[:vhs:]: https://asciinema.org/a/332147
[symmetricDifference]: https://github.com/nodef/extra-array/wiki/symmetricDifference

==> union-update-2.10.12.tgz: package/README.md <==
Gives values present in any array. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]

> Alternatives: [union], [union$].<br>
> Similar: [union], [intersection], [difference], [symmetricDifference].

> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

<br>

```javascript
array.union$(x, y, [fc], [fm]);
// x:  an array (updated)
// y:  another array
// fc: compare function (a, b)
// fm: map function (v, i, x)
// --> x
```
> :stopwatch: Compare function => O(n²).

```javascript
const array = require("extra-array");

var x = [1, 2, 3, 4];
var y = [2, 3, 5];
array.union$(x, y);
// [ 1, 2, 3, 4, 5 ]

x;
// [ 1, 2, 3, 4, 5 ]

var x = [1, 2, 3, 4];
var y = [-2, -3, -5];
array.union$(x, y, (a, b) => Math.abs(a) - Math.abs(b));
// [ 1, 2, 3, 4, -5 ]

var x = [1, 2, 3, 4];
array.union$(x, y, null, v => Math.abs(v));
// [ 1, 2, 3, 4, -5 ]
```

<br>
<br>


## References

- [Data.Set.union: Haskell](http://hackage.haskell.org/package/containers-0.6.2.1/docs/Data-Set.html#v:union)
- [Set.union: Python](https://www.programiz.com/python-programming/methods/set/union)
- [_.union: lodash](https://lodash.com/docs/4.17.15#union)
- [_.unionBy: lodash](https://lodash.com/docs/4.17.15#unionBy)
- [_.unionWith: lodash](https://lodash.com/docs/4.17.15#unionWith)
- [Array.union: sugarjs](https://sugarjs.com/docs/#/Array/union)

[:running:]: https://npm.runkit.com/@extra-array/union-update
[:package:]: https://www.npmjs.com/package/@extra-array/union-update
[:moon:]: https://www.npmjs.com/package/@extra-array/union-update.min
[:ledger:]: https://unpkg.com/@extra-array/union-update/
[union]: https://github.com/nodef/extra-array/wiki/union
[union$]: https://github.com/nodef/extra-array/wiki/union$
[intersection]: https://github.com/nodef/extra-array/wiki/intersection
[difference]: https://github.com/nodef/extra-array/wiki/difference
[unique]: https://github.com/nodef/extra-array/wiki/unique
[isUnique]: https://github.com/nodef/extra-array/wiki/isUnique
[isDisjoint]: https://github.com/nodef/extra-array/wiki/isDisjoint
[:vhs:]: https://asciinema.org/a/332147
[symmetricDifference]: https://github.com/nodef/extra-array/wiki/symmetricDifference
